<?php
/*
Plugin Name: WordPress CamelCase Zealot
Plugin URI: https://github.com/neilpie/WordPress-CamelCase-Zealot
Description: This plugin blindly enforces the CamelCase capitalisation of the text string 'WordPress' in as many places as I can think of. That includes URLs. Shame on me, eh? Use with caution.
Version: 0.2.2
Author: Neil Pie
Author URI: http://neilpie.co.uk
License: WTFPL
*/
/* This program is free software. It comes without any warranty, to
 * the extent permitted by applicable law. You can redistribute it
 * and/or modify it under the terms of the Do What The Fuck You Want
 * To Public License, Version 2, as published by Sam Hocevar. See
 * http://sam.zoy.org/wtfpl/COPYING for more details. */

class PieWordPressCamelCaseZealot {
	function __construct() {
		foreach(
			array(
				'widget_text',		// applied to the content of text widgets
				'widget_title',		// applied to title of user editable widgets
				'the_category',		// in lists only, not navigation
				'wp_list_categories',	// the html generated by this template tag
				'wp_tag_cloud',		// obv, no?
				'the_tags',		// applied to all tags before printing on screen
				'get_comment_text',	// applied to comment text after retrieving from the DB
				'the_title',		// obvious, no?
				'the_excerpt',		// see above
				'the_content',		// hits content & automatically generated excerpt
				'bloginfo'		// gets both the tagline & the site title
			) as $filter
		){
			add_filter($filter, array(&$this,'makeWordPress'));
		}
	}

	function makeWordPress($text){
		// if there's no 'wordpress' string, just send the text stright out
		if (stripos($text,'wordpress' === false)) return $text ;
		// if there's 'wordpress' in there somewhere, check they aren't already correctly cased. if they just send the text straight out
		if (substr_count($text, 'WordPress') === substr_count(strtolower($text), 'wordpress')) return $text;
		// if we're here then we run the replace
		return str_ireplace('wordpress','WordPress', $text);
	}
}

// only run the plugin if we're in the front end, otherwise it can play with the data. playing with other peple's data is bad.
if (!is_admin()) $PieWordPressCamelCaseZealot = new PieWordPressCamelCaseZealot;
